@@ -66,7 +66,7 @@ def change_sec_to_ffmpeg_time_format(time_input):
 def main():
     parser = argparse.ArgumentParser(prog='pim_video',
                                      description='PIM_VIDEO package.')
-    parser.add_argument('--version', action='version', version='1.0.0'),
+    parser.add_argument('--version', action='version', version='1.0.1'),
     parser.add_argument("-d", dest="input_directory", required=True, default=sys.stdin,
                         help="directory folder to be processed", metavar="directory name")
 
@@ -76,24 +76,41 @@ def main():
     # check whether input directory exists or not
     dir_exist = os.path.isdir(input_dir)
     if not dir_exist:
+        print("")
         print(f"Error! Input directory:{input_dir} does not exist.")
+        print("")
     else:
+        print("")
         print("Input directory is found.")
+        print("")
         file_name_array = ["gaze.csv", "left_eye_timestamp.csv",
                            "right_eye_timestamp.csv", "left_video.mp4", "right_video.mp4"]
         dir_exist_array = get_file_dir_exist_array(input_dir, file_name_array)
         all_file_found = True
         for exist_array in dir_exist_array:
             if not exist_array[1]:
+                print("")
                 print(f"Error! {exist_array[0]} file is missing.")
+                print("")
                 all_file_found = False
         if all_file_found:
+            print("")
             print("All necessary csv files and videos are found.")
+            print("")
             ffmpeg_check_cmd = "ffmpeg -version"
-            ffmpeg_check_output = subprocess.check_output(ffmpeg_check_cmd)
-            is_there_ffmpeg = "not found" not in ffmpeg_check_output.decode('utf-8')
+            try:
+                ffmpeg_check_output = subprocess.check_output(ffmpeg_check_cmd)
+            except FileNotFoundError:
+                ffmpeg_check_output = "not found"
+            try:
+                is_there_ffmpeg = "not " not in ffmpeg_check_output.decode('utf-8')
+            except AttributeError:
+                is_there_ffmpeg = False
+
             if is_there_ffmpeg:
+                print("")
                 print("Essential software, ffmpeg is found and start processing...")
+                print("")
                 os.chdir(input_dir)
 
                 # rotate the videos
@@ -103,19 +120,27 @@ def main():
                                      "right_video_rotated.mp4 "
                 os.system(left_v_rotate_cmd)
                 os.system(right_v_rotate_cmd)
+                print("")
                 print("Left and right videos have been rotated.")
+                print("")
 
                 # read left and right timestamps
                 left_csv_dir = os.path.join(input_dir, "left_eye_timestamp.csv")
                 left_timestamp = get_timestamp_from_csv(left_csv_dir, "left_eye_timestamp")
+                print("")
                 print(f"Left timestamp: {left_timestamp}")
+                print("")
                 right_csv_dir = os.path.join(input_dir, "right_eye_timestamp.csv")
                 right_timestamp = get_timestamp_from_csv(right_csv_dir, "right_eye_timestamp")
+                print("")
                 print(f"Right timestamp: {right_timestamp}")
+                print("")
                 timestamp_diff = round(left_timestamp - right_timestamp
                                        if left_timestamp >= right_timestamp
                                        else right_timestamp - left_timestamp, 3)
+                print("")
                 print(f"Timestamp difference: {timestamp_diff}")
+                print("")
                 timestamp_diff_ffmpeg_format = change_sec_to_ffmpeg_time_format(timestamp_diff)
 
                 # check the length of both rotated videos
@@ -125,10 +150,14 @@ def main():
                                         "-hide_banner "
                 left_v_len_check_output = subprocess.check_output(left_v_len_check_cmd).decode('utf-8')
                 left_v_length = get_video_length(left_v_len_check_output)
+                print("")
                 print(f"Left video length in sec: {left_v_length}")
+                print("")
                 right_v_len_check_output = subprocess.check_output(right_v_len_check_cmd).decode('utf-8')
                 right_v_length = get_video_length(right_v_len_check_output)
+                print("")
                 print(f"Right video length in sec: {right_v_length}")
+                print("")
 
                 # trimming the side which has earlier timestamp
                 trim_type = None
@@ -141,7 +170,9 @@ def main():
                                        f"-t {right_available_length_ffmpeg_format} " \
                                        f"-b:v 10M -c:a copy right_video_trimmed.mp4"
                     os.system(right_v_trim_cmd)
+                    print("")
                     print("Right video is trimmed.")
+                    print("")
                 else:
                     left_available_length = left_v_length - timestamp_diff
                     left_available_length_ffmpeg_format = change_sec_to_ffmpeg_time_format(left_available_length)
@@ -151,7 +182,9 @@ def main():
                                       f"-t {left_available_length_ffmpeg_format} " \
                                       f"-b:v 10M -c:a copy left_video_trimmed.mp4"
                     os.system(left_v_trim_cmd)
+                    print("")
                     print("Left video is trimmed.")
+                    print("")
 
                 # merge videos
                 right_trim_merge_cmd = "ffmpeg -i left_video_rotated.mp4 -i right_video_trimmed.mp4 -filter_complex " \
@@ -160,15 +193,21 @@ def main():
                                       "hstack=inputs=2:shortest=1 -b:v 10M -c:a copy left_right_combined.mp4 "
                 if trim_type == "right":
                     os.system(right_trim_merge_cmd)
+                    print("")
                     print("Left and right videos are merged into left_right_combined.mp4")
+                    print("")
                 elif trim_type == "left":
                     os.system(left_trim_merge_cmd)
+                    print("")
                     print("Left and right videos are merged into left_right_combined.mp4")
+                    print("")
                 else:
+                    print("")
                     print(f"Error! Trimming type is {trim_type}.")
                     pass
 
             else:
+                print("")
                 print("Essential software, ffmpeg is not found.")
                 print("Please read how to install ffmpeg from links below.")
                 print("For windows: https://www.wikihow.com/Install-FFmpeg-on-Windows")
